@@ -30,6 +30,13 @@ struct _CountdownHomeWidgetPrivate
 	GtkWidget *upButton, *downButton;
     GtkListStore *entries;
     guint refresh;
+	gchar *titleColor, *valueColor;
+	gchar *titleFont, *valueFont;
+	gboolean systemTitle, systemValue;
+	gboolean systemBG, systemButtonArea;
+	guint bgOpacity, buttonAreaOpacity;
+	gchar *bgColor, *buttonAreaColor;
+	guint radius;
 	guint offset;
     guint eventID;
 };
@@ -38,7 +45,7 @@ HD_DEFINE_PLUGIN_MODULE (CountdownHomeWidget, countdown_home_widget,
   HD_TYPE_HOME_PLUGIN_ITEM)
 
 gboolean countdown_home_widget_update_content (CountdownHomeWidget *self);
-static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event);
+static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event, CountdownHomeWidget *self);
 
 gboolean check_ampm_format ()
 {
@@ -90,6 +97,19 @@ void countdown_home_widget_write_settings (CountdownHomeWidget *self)
 	}
 	
 	g_key_file_set_integer (keyFile, "config", "refresh", self->priv->refresh);
+	g_key_file_set_boolean (keyFile, "config", "systemBG", self->priv->systemBG);
+	g_key_file_set_string (keyFile, "config", "bgColor", self->priv->bgColor);
+	g_key_file_set_integer (keyFile, "config", "bgOpacity", self->priv->bgOpacity);
+	g_key_file_set_integer (keyFile, "config", "radius", self->priv->radius);
+	g_key_file_set_boolean (keyFile, "config", "systemButtonArea", self->priv->systemButtonArea);
+	g_key_file_set_string (keyFile, "config", "buttonAreaColor", self->priv->buttonAreaColor);
+	g_key_file_set_integer (keyFile, "config", "buttonAreaOpacity", self->priv->buttonAreaOpacity);
+	g_key_file_set_boolean (keyFile, "config", "systemTitle", self->priv->systemTitle);
+	g_key_file_set_string (keyFile, "config", "titleColor", self->priv->titleColor);
+	g_key_file_set_string (keyFile, "config", "titleFont", self->priv->titleFont);
+	g_key_file_set_boolean (keyFile, "config", "systemValue", self->priv->systemValue);
+	g_key_file_set_string (keyFile, "config", "valueColor", self->priv->valueColor);
+	g_key_file_set_string (keyFile, "config", "valueFont", self->priv->valueFont);
 	
 	filename = g_strconcat (HOME_DIR, "/.countdown_home.ini", NULL);
 	fileData = g_key_file_to_data (keyFile, &size, NULL);
@@ -489,18 +509,93 @@ void countdown_home_widget_select_refresh (GtkButton *button, GtkWidget *dialog)
 	gtk_widget_hide (dialog);
 }
 
+void countdown_home_widget_select_bg_opacity (GtkButton *button, GtkWidget *dialog)
+{
+	HildonTouchSelector *selector = hildon_picker_dialog_get_selector (HILDON_PICKER_DIALOG (dialog));
+	gtk_widget_show_all (dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_button_set_label (button, hildon_touch_selector_get_current_text (selector));
+	gtk_widget_hide (dialog);	
+}
+
+void countdown_home_widget_select_radius (GtkButton *button, GtkWidget *dialog)
+{
+	HildonTouchSelector *selector = hildon_picker_dialog_get_selector (HILDON_PICKER_DIALOG (dialog));
+	gtk_widget_show_all (dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_button_set_label (button, hildon_touch_selector_get_current_text (selector));
+	gtk_widget_hide (dialog);
+}
+
+void countdown_home_widget_select_buttonArea_opacity (GtkButton *button, GtkWidget *dialog)
+{
+	HildonTouchSelector *selector = hildon_picker_dialog_get_selector (HILDON_PICKER_DIALOG (dialog));
+	gtk_widget_show_all (dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_button_set_label (button, hildon_touch_selector_get_current_text (selector));
+	gtk_widget_hide (dialog);
+}
+
+void countdown_home_widget_title_settings (GtkButton *button, GtkWidget *dialog)
+{
+	gtk_widget_show_all (dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_hide (dialog);
+}
+
+void countdown_home_widget_value_settings (GtkButton *button, GtkWidget *dialog)
+{
+	gtk_widget_show_all (dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_hide (dialog);
+}
+
+void countdown_home_widget_bg_settings (GtkButton *button, GtkWidget *dialog)
+{
+	gtk_widget_show_all (dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_hide (dialog);
+}
+
+void countdown_home_widget_system_settings (HildonCheckButton *button, GtkWidget *target)
+{
+	if (hildon_check_button_get_active (button)) {
+		gtk_button_set_label (GTK_BUTTON (target), "System style");
+	} else {
+		gtk_button_set_label (GTK_BUTTON (target), "User style");
+	}
+}
+
 void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_global_options");
     GtkWidget *dialog, *content_area;
-    GtkWidget *refreshButton;
-    GtkWidget *refreshCaption;
+    GtkWidget *refreshButton, *titleSettingsButton, *valueSettingsButton;
+	GtkWidget *bgSettingsButton, *buttonAreaSettingsButton;
+    GtkWidget *refreshCaption, *titleSettingsCaption, *valueSettingsCaption;
+	GtkWidget *bgSettingsCaption, *buttonAreaSettingsCaption;
+	GtkWidget *titleDialog, *valueDialog, *bgDialog, *buttonAreaDialog;
+	GtkWidget *titleContentArea, *valueContentArea, *bgContentArea, *buttonAreaContentArea;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	GtkSizeGroup *titleGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	GtkSizeGroup *valueGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	GtkSizeGroup *bgGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	GtkSizeGroup *buttonAreaGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	GdkColor color;
+	
+	titleSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	valueSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	bgSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	buttonAreaSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
 
-    dialog = gtk_dialog_new_with_buttons ("Global Countdown Settings",
+    dialog = gtk_dialog_new_with_buttons ("Countdown Settings",
         NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
         "Save", GTK_RESPONSE_ACCEPT, NULL);
-    content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+    GtkWidget *dialogContentArea = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+	GtkWidget *scroll = hildon_pannable_area_new ();
+	content_area = gtk_vbox_new (FALSE, 0);
+	hildon_pannable_area_add_with_viewport (HILDON_PANNABLE_AREA (scroll), content_area);
+	gtk_container_add (GTK_CONTAINER (dialogContentArea), scroll);
     
 	GtkWidget *picker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
 	gtk_window_set_title (GTK_WINDOW (picker), "Update Every");
@@ -515,24 +610,246 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	}
 	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, self->priv->refresh);
 	
+	titleDialog = gtk_dialog_new_with_buttons ("Title Settings", dialog,
+		GTK_DIALOG_DESTROY_WITH_PARENT, "Done", GTK_RESPONSE_ACCEPT, NULL);
+	titleContentArea = gtk_dialog_get_content_area (GTK_DIALOG (titleDialog));
+	
+	GtkWidget *titleSystemStyle = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON (titleSystemStyle), "Use system style");
+	hildon_check_button_set_active (HILDON_CHECK_BUTTON (titleSystemStyle), self->priv->systemTitle);
+	g_signal_connect (titleSystemStyle, "toggled", G_CALLBACK (countdown_home_widget_system_settings), titleSettingsButton);
+	GtkWidget *titleSystemStyleCaption = hildon_caption_new (titleGroup, "", titleSystemStyle, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (titleSystemStyleCaption), "");
+	gtk_container_add (GTK_CONTAINER (titleContentArea), titleSystemStyleCaption);
+	
+	GtkWidget *titleColorButton = gtk_color_button_new ();
+	gdk_color_parse (self->priv->titleColor, &color);
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (titleColorButton), &color);
+	hildon_gtk_widget_set_theme_size (titleColorButton, HILDON_SIZE_FINGER_HEIGHT);
+	GtkWidget *titleColorCaption = hildon_caption_new (titleGroup, "Font color", titleColorButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (titleColorCaption), "");
+	gtk_container_add (GTK_CONTAINER (titleContentArea), titleColorCaption);
+	
+	GtkWidget *titleFontButton = gtk_font_button_new ();
+	gtk_font_button_set_font_name (GTK_FONT_BUTTON (titleFontButton), self->priv->titleFont);
+	hildon_gtk_widget_set_theme_size (titleFontButton, HILDON_SIZE_FINGER_HEIGHT);
+	GtkWidget *titleFontCaption = hildon_caption_new (titleGroup, "Font style", titleFontButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (titleFontCaption), "");
+	gtk_container_add (GTK_CONTAINER (titleContentArea), titleFontCaption);
+	
+	valueDialog = gtk_dialog_new_with_buttons ("Value Settings", dialog,
+		GTK_DIALOG_DESTROY_WITH_PARENT, "Done", GTK_RESPONSE_ACCEPT, NULL);
+	valueContentArea = gtk_dialog_get_content_area (GTK_DIALOG (valueDialog));	
+	
+	GtkWidget *valueSystemStyle = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON (valueSystemStyle), "Use system style");
+	hildon_check_button_set_active (HILDON_CHECK_BUTTON (valueSystemStyle), self->priv->systemValue);
+	g_signal_connect (valueSystemStyle, "toggled", G_CALLBACK (countdown_home_widget_system_settings), valueSettingsButton);
+	GtkWidget *valueSystemStyleCaption = hildon_caption_new (valueGroup, "", valueSystemStyle, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (valueSystemStyleCaption), "");
+	gtk_container_add (GTK_CONTAINER (valueContentArea), valueSystemStyleCaption);	
+	
+	GtkWidget *valueColorButton = gtk_color_button_new ();
+	gdk_color_parse (self->priv->valueColor, &color);
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (valueColorButton), &color);
+	hildon_gtk_widget_set_theme_size (valueColorButton, HILDON_SIZE_FINGER_HEIGHT);
+	GtkWidget *valueColorCaption = hildon_caption_new (valueGroup, "Font color", valueColorButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (valueColorCaption), "");
+	gtk_container_add (GTK_CONTAINER (valueContentArea), valueColorCaption);
+	
+	GtkWidget *valueFontButton = gtk_font_button_new ();
+	gtk_font_button_set_font_name (GTK_FONT_BUTTON (valueFontButton), self->priv->valueFont);
+	hildon_gtk_widget_set_theme_size (valueFontButton, HILDON_SIZE_FINGER_HEIGHT);
+	GtkWidget *valueFontCaption = hildon_caption_new (valueGroup, "Font style", valueFontButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (valueFontCaption), "");
+	gtk_container_add (GTK_CONTAINER (valueContentArea), valueFontCaption);
+	
+	bgDialog = gtk_dialog_new_with_buttons ("Background Settings", dialog,
+		GTK_DIALOG_DESTROY_WITH_PARENT, "Done", GTK_RESPONSE_ACCEPT, NULL);
+	bgContentArea = gtk_dialog_get_content_area (GTK_DIALOG (bgDialog));
+	
+	GtkWidget *bgSystemStyle = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON (bgSystemStyle), "Use system style");
+	hildon_check_button_set_active (HILDON_CHECK_BUTTON (bgSystemStyle), self->priv->systemBG);
+	g_signal_connect (bgSystemStyle, "toggled", G_CALLBACK (countdown_home_widget_system_settings), bgSettingsButton);
+	GtkWidget *bgSystemStyleCaption = hildon_caption_new (bgGroup, "", bgSystemStyle, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (bgSystemStyleCaption), "");
+	gtk_container_add (GTK_CONTAINER (bgContentArea), bgSystemStyleCaption);	
+	
+	GtkWidget *bgColorButton = gtk_color_button_new ();
+	gdk_color_parse (self->priv->bgColor, &color);
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (bgColorButton), &color);
+	hildon_gtk_widget_set_theme_size (bgColorButton, HILDON_SIZE_FINGER_HEIGHT);
+	GtkWidget *bgColorCaption = hildon_caption_new (bgGroup, "Background color", bgColorButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (bgColorCaption), "");
+	gtk_container_add (GTK_CONTAINER (bgContentArea), bgColorCaption);
+	
+	GtkWidget *bgOpacityPicker = hildon_picker_dialog_new (GTK_WINDOW (bgDialog));
+	gtk_window_set_title (GTK_WINDOW (bgOpacityPicker), "Background opacity");
+	GtkWidget *bgOpacitySelector = hildon_touch_selector_new_text ();
+	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (bgOpacityPicker), HILDON_TOUCH_SELECTOR (bgOpacitySelector));
+	
+	for (i=0; i<=100; i++) {
+		gchar *text = g_strdup_printf ("%d%%", i);
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (bgOpacitySelector), text);
+		g_free (text);
+	}
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (bgOpacitySelector), 0, self->priv->bgOpacity);
+	GtkWidget *bgOpacityButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	g_signal_connect (G_OBJECT (bgOpacityButton), "clicked", G_CALLBACK (countdown_home_widget_select_bg_opacity), bgOpacityPicker);
+	gchar *name = g_strdup_printf ("%d%%", self->priv->bgOpacity);
+	gtk_button_set_label (GTK_BUTTON (bgOpacityButton), name);
+	g_free (name);
+	GtkWidget *bgOpacityCaption = hildon_caption_new (bgGroup, "Background opacity", bgOpacityButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (bgOpacityCaption), "");
+	gtk_container_add (GTK_CONTAINER (bgContentArea), bgOpacityCaption);
+	
+	buttonAreaDialog = gtk_dialog_new_with_buttons ("Button Area Settings", dialog,
+		GTK_DIALOG_DESTROY_WITH_PARENT, "Done", GTK_RESPONSE_ACCEPT, NULL);
+	buttonAreaContentArea = gtk_dialog_get_content_area (GTK_DIALOG (buttonAreaDialog));
+	
+	GtkWidget *buttonAreaSystemStyle = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON (buttonAreaSystemStyle), "Use system style");
+	hildon_check_button_set_active (HILDON_CHECK_BUTTON (buttonAreaSystemStyle), self->priv->systemButtonArea);
+	g_signal_connect (buttonAreaSystemStyle, "toggled", G_CALLBACK (countdown_home_widget_system_settings), buttonAreaSettingsButton);
+	GtkWidget *buttonAreaSystemStyleCaption = hildon_caption_new (buttonAreaGroup, "", buttonAreaSystemStyle, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (buttonAreaSystemStyleCaption), "");
+	gtk_container_add (GTK_CONTAINER (buttonAreaContentArea), buttonAreaSystemStyleCaption);	
+	
+	GtkWidget *buttonAreaColorButton = gtk_color_button_new ();
+	gdk_color_parse (self->priv->buttonAreaColor, &color);
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (buttonAreaColorButton), &color);
+	hildon_gtk_widget_set_theme_size (buttonAreaColorButton, HILDON_SIZE_FINGER_HEIGHT);
+	GtkWidget *buttonAreaColorCaption = hildon_caption_new (buttonAreaGroup, "Background color", buttonAreaColorButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (buttonAreaColorCaption), "");
+	gtk_container_add (GTK_CONTAINER (buttonAreaContentArea), buttonAreaColorCaption);
+	
+	GtkWidget *buttonAreaOpacityPicker = hildon_picker_dialog_new (GTK_WINDOW (buttonAreaDialog));
+	gtk_window_set_title (GTK_WINDOW (buttonAreaOpacityPicker), "Background opacity");
+	GtkWidget *buttonAreaOpacitySelector = hildon_touch_selector_new_text ();
+	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (buttonAreaOpacityPicker), HILDON_TOUCH_SELECTOR (buttonAreaOpacitySelector));
+	
+	for (i=0; i<=100; i++) {
+		gchar *text = g_strdup_printf ("%d%%", i);
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (buttonAreaOpacitySelector), text);
+		g_free (text);
+	}
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (buttonAreaOpacitySelector), 0, self->priv->buttonAreaOpacity);
+	GtkWidget *buttonAreaOpacityButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	g_signal_connect (G_OBJECT (buttonAreaOpacityButton), "clicked", G_CALLBACK (countdown_home_widget_select_buttonArea_opacity), buttonAreaOpacityPicker);
+	name = g_strdup_printf ("%d%%", self->priv->buttonAreaOpacity);
+	gtk_button_set_label (GTK_BUTTON (buttonAreaOpacityButton), name);
+	g_free (name);
+	GtkWidget *buttonAreaOpacityCaption = hildon_caption_new (buttonAreaGroup, "Background opacity", buttonAreaOpacityButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (buttonAreaOpacityCaption), "");
+	gtk_container_add (GTK_CONTAINER (buttonAreaContentArea), buttonAreaOpacityCaption);
+	
 	refreshButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
 	g_signal_connect (G_OBJECT (refreshButton), "clicked", G_CALLBACK (countdown_home_widget_select_refresh), picker);
 	
 	gchar *text = g_strdup_printf ("%d minute(s)", self->priv->refresh);
 	gtk_button_set_label (GTK_BUTTON (refreshButton), text);
+	g_free (text);
 	
 	refreshCaption = hildon_caption_new (group, "Update every", refreshButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (refreshCaption), "");
-	
     gtk_container_add (GTK_CONTAINER (content_area), refreshCaption);
+	
+	if (self->priv->systemTitle) {
+		gtk_button_set_label (GTK_BUTTON (titleSettingsButton), "System style");
+	} else {
+		gtk_button_set_label (GTK_BUTTON (titleSettingsButton), "User style");
+	}
+	g_signal_connect (titleSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_title_settings), titleDialog);
+	
+	titleSettingsCaption = hildon_caption_new (group, "Title", titleSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (titleSettingsCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), titleSettingsCaption);
+
+	if (self->priv->systemValue) {
+		gtk_button_set_label (GTK_BUTTON (valueSettingsButton), "System style");
+	} else {
+		gtk_button_set_label (GTK_BUTTON (valueSettingsButton), "User style");
+	}
+	g_signal_connect (valueSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_value_settings), valueDialog);
+	
+	valueSettingsCaption = hildon_caption_new (group, "Value", valueSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (valueSettingsCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), valueSettingsCaption);
+	
+	if (self->priv->systemBG) {
+		gtk_button_set_label (GTK_BUTTON (bgSettingsButton), "System style");
+	} else {
+		gtk_button_set_label (GTK_BUTTON (bgSettingsButton), "User style");
+	}
+	g_signal_connect (bgSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_bg_settings), bgDialog);
+
+	bgSettingsCaption = hildon_caption_new (group, "Background", bgSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (bgSettingsCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), bgSettingsCaption);	
+
+	if (self->priv->systemButtonArea) {
+		gtk_button_set_label (GTK_BUTTON (buttonAreaSettingsButton), "System style");
+	} else {
+		gtk_button_set_label (GTK_BUTTON (buttonAreaSettingsButton), "User style");
+	}
+	g_signal_connect (buttonAreaSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_bg_settings), buttonAreaDialog);
+
+	buttonAreaSettingsCaption = hildon_caption_new (group, "Button area", buttonAreaSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (buttonAreaSettingsCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), buttonAreaSettingsCaption);	
+
+	GtkWidget *radiusPicker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
+	gtk_window_set_title (GTK_WINDOW (radiusPicker), "Corner radius");
+	GtkWidget *radiusSelector = hildon_touch_selector_new_text ();
+	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (radiusPicker), HILDON_TOUCH_SELECTOR (radiusSelector));
+	
+	for (i=0; i<=25; i++) {
+		gchar *text = g_strdup_printf ("%d", i);
+		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (radiusSelector), text);
+		g_free (text);
+	}
+	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (radiusSelector), 0, self->priv->radius);
+	GtkWidget *radiusButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	g_signal_connect (G_OBJECT (radiusButton), "clicked", G_CALLBACK (countdown_home_widget_select_radius), radiusPicker);
+	name = g_strdup_printf ("%d", self->priv->radius);
+	gtk_button_set_label (GTK_BUTTON (radiusButton), name);
+	g_free (name);
+	GtkWidget *radiusCaption = hildon_caption_new (group, "Corner radius", radiusButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (radiusCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), radiusCaption);
+
+	gtk_window_set_default_size (GTK_WINDOW (dialog), -1, 300);
 
     gtk_widget_show_all (dialog);
 
     int response=gtk_dialog_run (GTK_DIALOG (dialog));
     if (response == GTK_RESPONSE_ACCEPT) {
-		gint refresh = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
-		self->priv->refresh = refresh;
+		GdkColor color;
+		self->priv->refresh = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
 		
+		self->priv->systemTitle = hildon_check_button_get_active (HILDON_CHECK_BUTTON (titleSystemStyle));
+		gtk_color_button_get_color (GTK_COLOR_BUTTON (titleColorButton), &color);
+		self->priv->titleColor = gdk_color_to_string (&color);
+		self->priv->titleFont = g_markup_escape_text(gtk_font_button_get_font_name (GTK_FONT_BUTTON (titleFontButton)), -1);
+		
+		self->priv->systemValue = hildon_check_button_get_active (HILDON_CHECK_BUTTON (valueSystemStyle));
+		gtk_color_button_get_color (GTK_COLOR_BUTTON (valueColorButton), &color);
+		self->priv->valueColor = gdk_color_to_string (&color);
+		self->priv->valueFont = g_markup_escape_text(gtk_font_button_get_font_name (GTK_FONT_BUTTON (valueFontButton)), -1);
+		
+		self->priv->systemBG = hildon_check_button_get_active (HILDON_CHECK_BUTTON (bgSystemStyle));
+		gtk_color_button_get_color (GTK_COLOR_BUTTON (bgColorButton), &color);
+		self->priv->bgColor = gdk_color_to_string (&color);
+		self->priv->bgOpacity = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (bgOpacitySelector), 0);
+		
+		self->priv->radius = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (radiusSelector), 0);
+		
+		self->priv->systemButtonArea = hildon_check_button_get_active (HILDON_CHECK_BUTTON (buttonAreaSystemStyle));
+		gtk_color_button_get_color (GTK_COLOR_BUTTON (buttonAreaColorButton), &color);
+		self->priv->buttonAreaColor = gdk_color_to_string (&color);
+		self->priv->buttonAreaOpacity = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (buttonAreaOpacitySelector), 0);
+				
 		if (self->priv->eventID != 0) {
 			g_source_remove (self->priv->eventID);
 			if (self->priv->refresh > 0) {
@@ -542,6 +859,7 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 		
 		countdown_home_widget_write_settings (self);
 		countdown_home_widget_update_content (self);
+		gtk_widget_queue_draw (self);
     }
     gtk_widget_destroy (dialog);
 }
@@ -621,8 +939,99 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
             g_error_free (error);
             error = NULL;
         }
+		self->priv->systemBG = g_key_file_get_boolean (keyFile, "config", "systemBG", &error);
+		if (error) {
+			self->priv->systemBG = TRUE;
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->bgColor = g_key_file_get_string (keyFile, "config", "bgColor", &error);
+		if (error) {
+			self->priv->bgColor = "#000000";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->bgOpacity = g_key_file_get_integer (keyFile, "config", "bgOpacity", &error);
+		if (error) {
+			self->priv->bgOpacity = 25;
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->radius = g_key_file_get_integer (keyFile, "config", "radius", &error);
+		if (error) {
+			self->priv->radius = 10;
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->systemButtonArea = g_key_file_get_boolean (keyFile, "config", "systemButtonArea", &error);
+		if (error) {
+			self->priv->systemButtonArea = TRUE;
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->buttonAreaColor = g_key_file_get_string (keyFile, "config", "buttonAreaColor", &error);
+		if (error) {
+			self->priv->buttonAreaColor = "#000000";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->buttonAreaOpacity = g_key_file_get_integer (keyFile, "config", "buttonAreaOpacity", &error);
+		if (error) {
+			self->priv->buttonAreaOpacity = 50;
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->systemTitle = g_key_file_get_boolean (keyFile, "config", "systemTitle", &error);
+		if (error) {
+			self->priv->systemTitle = TRUE;
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->titleColor = g_key_file_get_string (keyFile, "config", "titleColor", &error);
+		if (error) {
+			self->priv->titleColor = "#ffffff";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->titleFont = g_key_file_get_string (keyFile, "config", "titleFont", &error);
+		if (error) {
+			self->priv->titleFont = "Sans 18";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->systemValue = g_key_file_get_boolean (keyFile, "config", "systemValue", &error);
+		if (error) {
+			self->priv->systemValue = TRUE;
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->valueColor = g_key_file_get_string (keyFile, "config", "valueColor", &error);
+		if (error) {
+			self->priv->valueColor = "#ababab";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->valueFont = g_key_file_get_string (keyFile, "config", "valueFont", &error);
+		if (error) {
+			self->priv->valueFont = "Sans 16";
+			g_error_free (error);
+			error = NULL;
+		}
     } else {
         self->priv->refresh = 1;
+		self->priv->systemBG = TRUE;
+		self->priv->bgOpacity = 25;
+		self->priv->bgColor = "#000000";
+		self->priv->radius = 10;
+		self->priv->systemButtonArea = TRUE;
+		self->priv->buttonAreaOpacity = 50;
+		self->priv->buttonAreaColor = "#000000";
+		self->priv->systemTitle = TRUE;
+		self->priv->titleColor = "#ffffff";
+		self->priv->titleFont = "Sans 18";
+		self->priv->systemValue = TRUE;
+		self->priv->valueColor = "#ababab";
+		self->priv->valueFont = "Sans 16";
     }
 
     g_key_file_free (keyFile);
@@ -680,7 +1089,7 @@ void countdown_home_widget_content_create (CountdownHomeWidget *self)
 	gtk_container_add (GTK_CONTAINER (self->priv->homeWidget), align);
     gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->buttons), FALSE, FALSE, 0);
 	
-	g_signal_connect (self->priv->buttons, "expose-event", G_CALLBACK (countdown_home_widget_expose_button_area), NULL);
+	g_signal_connect (self->priv->buttons, "expose-event", G_CALLBACK (countdown_home_widget_expose_button_area), self);
 	
     gtk_widget_show_all (self->priv->homeWidget);
 }
@@ -825,11 +1234,19 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 			GtkWidget *vbox = gtk_vbox_new (TRUE, 0);
 			GtkWidget *titleLabel = gtk_label_new (title);
 			gtk_label_set_ellipsize (GTK_LABEL (titleLabel), PANGO_ELLIPSIZE_END);
+			if (!self->priv->systemTitle) {
+				gtk_label_set_markup (GTK_LABEL (titleLabel), g_strconcat ("<span font=\"", self->priv->titleFont,"\" color=\"",self->priv->titleColor, "\">", title, "</span>", NULL));
+			}
 			GtkWidget *contentLabel = gtk_label_new (contentLabelText);
-			GdkColor color;
-			gtk_style_lookup_color (gtk_rc_get_style(contentLabel), "SecondaryTextColor", &color);
-			gtk_label_set_markup (GTK_LABEL (contentLabel), g_strconcat ("<span size=\"smaller\" color=\"",gdk_color_to_string (&color),"\">", contentLabelText, "</span>", NULL));
 			gtk_label_set_ellipsize (GTK_LABEL (contentLabel), PANGO_ELLIPSIZE_END);
+			
+			if (self->priv->systemValue) {
+				GdkColor color;
+				gtk_style_lookup_color (gtk_rc_get_style(contentLabel), "SecondaryTextColor", &color);
+				gtk_label_set_markup (GTK_LABEL (contentLabel), g_strconcat ("<span size=\"smaller\" color=\"",gdk_color_to_string (&color),"\">", contentLabelText, "</span>", NULL));
+			} else {
+				gtk_label_set_markup (GTK_LABEL (contentLabel), g_strconcat ("<span font=\"", self->priv->valueFont,"\" color=\"",self->priv->valueColor, "\">", contentLabelText, "</span>", NULL));
+			}
 
 			gtk_container_add (GTK_CONTAINER (event), vbox);
 			gtk_container_add (GTK_CONTAINER (vbox), titleLabel);
@@ -941,7 +1358,7 @@ static void countdown_home_widget_realize (GtkWidget *widget)
 	GTK_WIDGET_CLASS (countdown_home_widget_parent_class)->realize (widget);
 }
 
-static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event)
+static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, GdkEventExpose *event, CountdownHomeWidget *self)
 {
 	cairo_t *cr;
 
@@ -950,26 +1367,29 @@ static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, Gdk
 	cairo_clip (cr);
 
     cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-    cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
+	if (self->priv->systemButtonArea) {
+		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
+	} else {
+		GdkColor color;
+		gdk_color_parse (self->priv->buttonAreaColor, &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65535.0, color.blue/65535.0, self->priv->buttonAreaOpacity/100.0);
+	}
     
-	gint width, height, x, y, radius=10;
+	gint width, height, x, y;
 	width = widget->allocation.width;
 	height = widget->allocation.height;
 	x = widget->allocation.x;
 	y = widget->allocation.y;
 
-	cairo_move_to(cr, x + radius, y);
-	cairo_line_to(cr, x + width - radius, y);
-	cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
-				y + radius);
-	cairo_line_to(cr, x + width, y + height - radius);
-	cairo_curve_to(cr, x + width, y + height - radius, x + width,
-				y + height, x + width - radius, y + height);
-	cairo_line_to(cr, x + radius, y + height);
-	cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
-				y + height - radius);
-	cairo_line_to(cr, x, y + radius);
-	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
+	cairo_move_to(cr, x + self->priv->radius, y);
+	cairo_line_to(cr, x + width, y);
+	cairo_line_to(cr, x + width, y + height - self->priv->radius);
+	cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+				y + height, x + width - self->priv->radius, y + height);
+	cairo_line_to(cr, x + self->priv->radius, y + height);
+	cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+				y + height - self->priv->radius);
+	cairo_line_to(cr, x, y);
 
 	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
@@ -983,6 +1403,7 @@ static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, Gdk
 static gboolean countdown_home_widget_expose_event (GtkWidget *widget, GdkEventExpose *event)
 {
 	//g_warning ("countdown_home_widget_expose_event");
+	CountdownHomeWidget *self = COUNTDOWN_HOME_WIDGET (widget);
 	cairo_t *cr;
 
     cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
@@ -994,26 +1415,32 @@ static gboolean countdown_home_widget_expose_event (GtkWidget *widget, GdkEventE
     cairo_destroy (cr);
 	
 	cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
-	cairo_set_source_rgba (cr, 0.25, 0.25, 0.25, 0.5);
+	if (self->priv->systemBG) {
+		cairo_set_source_rgba (cr, 0.25, 0.25, 0.25, 0.25);
+	} else {
+		GdkColor color;
+		gdk_color_parse (self->priv->bgColor, &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65535.0, color.blue/65535.0, self->priv->bgOpacity/100.0);
+	}
 	
-	gint width, height, x, y, radius=10;
+	gint width, height, x, y;
 	width = widget->allocation.width;
 	height = widget->allocation.height;
 	x = widget->allocation.x;
 	y = widget->allocation.y;
 
-	cairo_move_to(cr, x + radius, y);
-	cairo_line_to(cr, x + width - radius, y);
-	cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
-				y + radius);
-	cairo_line_to(cr, x + width, y + height - radius);
-	cairo_curve_to(cr, x + width, y + height - radius, x + width,
-				y + height, x + width - radius, y + height);
-	cairo_line_to(cr, x + radius, y + height);
-	cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
-				y + height - radius);
-	cairo_line_to(cr, x, y + radius);
-	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
+	cairo_move_to(cr, x + self->priv->radius, y);
+	cairo_line_to(cr, x + width - self->priv->radius, y);
+	cairo_curve_to(cr, x + width - self->priv->radius, y, x + width, y, x + width,
+				y + self->priv->radius);
+	cairo_line_to(cr, x + width, y + height - self->priv->radius);
+	cairo_curve_to(cr, x + width, y + height - self->priv->radius, x + width,
+				y + height, x + width - self->priv->radius, y + height);
+	cairo_line_to(cr, x + self->priv->radius, y + height);
+	cairo_curve_to(cr, x + self->priv->radius, y + height, x, y + height, x,
+				y + height - self->priv->radius);
+	cairo_line_to(cr, x, y + self->priv->radius);
+	cairo_curve_to(cr, x, y + self->priv->radius, x, y, x + self->priv->radius, y);
 
 	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
